[PATCH] D34514: [mips] Enable IAS by default for Android 64-bit MIPS target (N64)

Petar Jovanovic via Phabricator via cfe-commits cfe-commits at lists.llvm.org
Mon Jun 26 02:58:14 PDT 2017


This revision was automatically updated to reflect the committed changes.
Closed by commit rL306280: [mips] Enable IAS by default for Android 64-bit MIPS target (N64) (authored by petarj).

Changed prior to commit:
  https://reviews.llvm.org/D34514?vs=103574&id=103912#toc

Repository:
  rL LLVM

https://reviews.llvm.org/D34514

Files:
  cfe/trunk/lib/Driver/ToolChains/Gnu.cpp


Index: cfe/trunk/lib/Driver/ToolChains/Gnu.cpp
===================================================================
--- cfe/trunk/lib/Driver/ToolChains/Gnu.cpp
+++ cfe/trunk/lib/Driver/ToolChains/Gnu.cpp
@@ -2338,9 +2338,11 @@
     return true;
   case llvm::Triple::mips64:
   case llvm::Triple::mips64el:
-    // Enabled for Debian mips64/mips64el only. Other targets are unable to
-    // distinguish N32 from N64.
-    if (getTriple().getEnvironment() == llvm::Triple::GNUABI64)
+    // Enabled for Debian and Android mips64/mipsel, as they can precisely
+    // identify the ABI in use (Debian) or only use N64 for MIPS64 (Android).
+    // Other targets are unable to distinguish N32 from N64.
+    if (getTriple().getEnvironment() == llvm::Triple::GNUABI64 ||
+        getTriple().isAndroid())
       return true;
     return false;
   default:


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D34514.103912.patch
Type: text/x-patch
Size: 851 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/cfe-commits/attachments/20170626/5c63628d/attachment.bin>


More information about the cfe-commits mailing list